# Mixcloud RSS Feed Generator

Dieses Python-Script erstellt einen RSS-Feed aus deinen Mixcloud-Tracks, damit du sie über Podcast-Apps abonnieren und anhören kannst.

## Installation

1. Abhängigkeiten installieren:

   ```bash
   uv pip install -r requirements.txt
   ```

## Verwendung

### RSS-Feed mit echten Audio-URLs erstellen (empfohlen)

```bash
uv run python mixcloud_rss_pro.py serman_dj
```

Das erstellt eine `mixcloud_feed.xml` Datei mit **echten Audio-Streams**, die in Podcast-Apps abspielbar sind.

### Original-Version (nur Mixcloud-Links)

```bash
python mixcloud_rss.py serman_dj
```

### Erweiterte Optionen

```bash
# Feed mit 100 Tracks erstellen (mit Audio-URLs)
uv run python mixcloud_rss_pro.py serman_dj --limit 100

# Feed in spezifische Datei speichern
uv run python mixcloud_rss_pro.py serman_dj --output mein_feed.xml

# Schnellmodus ohne Audio-Extraktion
uv run python mixcloud_rss_pro.py serman_dj --no-audio

# HTTP-Server starten für den Feed
uv run python mixcloud_rss_pro.py serman_dj --serve

# Server-Wrapper verwenden (automatische Updates)
python start_server.py
```

### RSS-Feed in Podcast-App hinzufügen

1. **Mit HTTP-Server (empfohlen):**
   - Starte den Server: `python mixcloud_rss.py serman_dj --serve`
   - Füge diese URL in deiner Podcast-App hinzu: `http://localhost:8000/mixcloud_feed.xml`

2. **Feed-Datei hosten:**
   - Lade die generierte XML-Datei auf einen Webserver hoch
   - Verwende die öffentliche URL in deiner Podcast-App

## Funktionen

- ✅ **Echte Audio-URLs**: Extrahiert direkte Audio-Streams für Podcast-Apps
- ✅ Holt automatisch deine neuesten Mixcloud-Tracks
- ✅ Erstellt RSS-Feed im Podcast-Format
- ✅ Unterstützt iTunes-Tags für bessere Kompatibilität
- ✅ Inkludiert Track-Metadaten (Titel, Beschreibung, Dauer, Tags)
- ✅ Eingebauter HTTP-Server zum Testen
- ✅ Konfigurierbare Anzahl von Tracks
- ✅ Parallele Audio-URL-Extraktion für bessere Performance

## Audio-Streaming

🎉 **Problem gelöst!** Das neue `mixcloud_rss_pro.py` Script extrahiert echte Audio-URLs, die in Podcast-Apps abspielbar sind:

- ✅ Direkte `.m4a` Audio-Streams
- ✅ Korrekte Content-Types für Podcast-Apps
- ✅ Funktioniert mit Apple Podcasts, Spotify, etc.

## Bekannte Einschränkungen

~~**Audio-Streaming:** Mixcloud erlaubt kein direktes Audio-Streaming ohne Autorisierung.~~

**✅ Gelöst:** Mit `yt-dlp` werden jetzt echte Audio-URLs extrahiert!

## Troubleshooting

### "Keine Cloudcasts gefunden"

- Überprüfe den Benutzernamen
- Stelle sicher, dass das Profil öffentlich ist

### RSS-Feed wird nicht in Podcast-App erkannt

- Überprüfe, ob der HTTP-Server läuft
- Teste die URL im Browser: `http://localhost:8000/mixcloud_feed.xml`
- Verwende die Pro-Version: `uv run python mixcloud_rss_pro.py serman_dj`

### Audio wird nicht abgespielt

- ✅ **Gelöst:** Verwende `mixcloud_rss_pro.py` für echte Audio-URLs
- Die Pro-Version extrahiert direkte Audio-Streams
- Dauert länger, aber funktioniert in allen Podcast-Apps

## Beispiel-Ausgabe

```text
Erstelle RSS-Feed für Mixcloud-User: serman_dj
RSS-Feed erfolgreich erstellt: mixcloud_feed.xml
Anzahl der Episoden: 50
```

## Automatisierung

Du kannst das Script regelmäßig ausführen lassen, um den Feed aktuell zu halten:

```bash
# Crontab-Eintrag für tägliche Updates um 6:00 Uhr
0 6 * * * cd /pfad/zu/rss-feeder && python mixcloud_rss.py serman_dj
```
